@@ -1,19 +1,18 @@
 from __future__ import annotations
 
+import sys
 from typing import TYPE_CHECKING
 
 from flake8_typing_only_imports.checker import TypingOnlyImportsChecker
 from flake8_typing_only_imports.constants import disabled_by_default
 
 if TYPE_CHECKING:
+    from argparse import Namespace
     from ast import Module
     from typing import Generator
-    from argparse import Namespace
 
     from flake8.options.manager import OptionManager
 
-import sys
-
 if sys.version_info >= (3, 8):
     from importlib.metadata import version
 else:
@@ -39,5 +38,5 @@ class Plugin:
 
     @staticmethod
     def parse_options(optmanager: OptionManager, options: Namespace, extra_args: list) -> None:
-        """Informs flake8 to ignore TYO101 and TYO3XX by default."""
+        """Informs flake8 to ignore all errors except TYO100."""
         optmanager.extend_default_ignore(disabled_by_default)
